.. pysamloader documentation master file, created by
   sphinx-quickstart on Sun Jan 27 04:56:49 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pysamloader Documentation
-------------------------

.. toctree::
    :maxdepth: 3

    readme


.. only:: html

    Indices and tables
    ------------------

    * :ref:`genindex`
    * :ref:`modindex`
    * :ref:`search`
